## Getting Started

**warning "Alpha Software!"**

This is pre-release Alpha software, based on another code base and
the needed changes to make a final release version are not yet
completed. Everything is subject to change; and documentation needs
to be written.


```shell
poetry install xmodel-rest
```

or

```shell
pip install xmodel-rest
```
